@@ -31,6 +31,10 @@ the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 #include <stdlib.h>
 #endif
 
+#ifdef TCL_NETGEN
+#include <tcl.h>
+#endif
+
 #include "netgen.h"
 #include "hash.h"
 #include "objlist.h"
@@ -346,10 +350,9 @@ void PRINTPACKED(unsigned long *mstar)
 
 
 #ifdef IBMPC
-static unsigned int hash(unsigned long *mstar)
+static unsigned int lochash(unsigned long *mstar)
 #else
-INLINE 
-static unsigned long hash(unsigned long *mstar)
+static unsigned long lochash(unsigned long *mstar)
 #endif
 {
   int i;
@@ -386,7 +389,7 @@ struct ex_entry *hashlookup(unsigned long *mstar)
   struct ex_entry *np;
   int i;
 
-  for (np = ex_tab[hash(mstar)]; np != NULL; np = np->next) 
+  for (np = ex_tab[lochash(mstar)]; np != NULL; np = np->next) 
     for (i = 0; i <= PackedLeaves && mstar[i] == (np->mstar)[i]; i++) 
       if (i == PackedLeaves) {
 #ifdef EXTREE_DEBUG
@@ -410,7 +413,7 @@ static struct ex_entry *hashinstall(unsigned long *mstar)
 #endif
   int i;
 
-  hashval = hash(mstar);
+  hashval = lochash(mstar);
   for (np = ex_tab[hashval]; np != NULL; np = np->next) 
     for (i = 0; i <= PackedLeaves && mstar[i] == (np->mstar)[i]; i++) 
       if (i == PackedLeaves) {
@@ -432,7 +435,6 @@ static struct ex_entry *hashinstall(unsigned long *mstar)
   return(ex_tab[hashval] = np);
 }
 
-/* INLINE */
 int Exists(int E1, int E2)
 {
   int i;
@@ -470,7 +472,6 @@ int InitializeExistTest(void)
   return(1);
 }
 
-/* INLINE */
 void AddToExistSet(int E1, int E2) 
 {
   int i;
@@ -580,7 +581,7 @@ struct embed *FlattenEmbeddingTree(struct embed *E)
     struct objlist *ob;
 
     ob = InstanceNumber(E->cell,E->instancenumber);
-    tp = LookupCell(ob->model);
+    tp = LookupCell(ob->model.class);
 
     if (tp->embedding != NULL) {
       tmp = FlattenEmbeddingTree((struct embed *)(tp->embedding));
@@ -628,7 +629,7 @@ struct embed *FlattenEmbeddingTree(struct embed *E)
 int LenEmbed(char *prefix, struct nlist *np, struct embed *E, int flatten)
 /* return the number of characters required to print element E */
 {
-  char longstr[200];
+  char longstr[MAX_STR_LEN];
 
   if (E == NULL) return(0);
   if (E->left == NULL && E->right == NULL) {
@@ -639,8 +640,8 @@ int LenEmbed(char *prefix, struct nlist *np, struct embed *E, int flatten)
     struct nlist *np2;
 
     ob = InstanceNumber(np,E->instancenumber);
-    instancename = ob->instance;
-    model = ob->model;
+    instancename = ob->instance.name;
+    model = ob->model.class;
     np2 = LookupCell(model);
     if (np2 == NULL) return(0);
     sprintf(longstr, "%s%s", prefix, instancename);
@@ -667,11 +668,11 @@ void PrintEmb(FILE *outfile, char *prefix, struct nlist *np,
     struct objlist *ob;
     char *instancename;
     struct nlist *np2;
-    char name[200];
+    char name[MAX_STR_LEN];
 
     ob = InstanceNumber(np,E->instancenumber);
-    instancename = ob->instance;
-    np2 = LookupCell(ob->model);
+    instancename = ob->instance.name;
+    np2 = LookupCell(ob->model.class);
     if (np2 == NULL) return;
      sprintf(name,"%s%s", prefix, instancename);
     if ((np2->class != CLASS_SUBCKT) || np2->embedding == NULL || !flatten) 
@@ -705,11 +706,11 @@ void PrintEmbed(FILE *outfile, char *prefix, struct nlist *np,
     struct objlist *ob;
     char *instancename;
     struct nlist *np2;
-    char name[200];
+    char name[MAX_STR_LEN];
 
     ob = InstanceNumber(np,E->instancenumber);
-    instancename = ob->instance;
-    np2 = LookupCell(ob->model);
+    instancename = ob->instance.name;
+    np2 = LookupCell(ob->model.class);
     if (np2 == NULL) return;
 
     if (np2->embedding != NULL && flatten) {
