@@ -195,7 +195,7 @@ int InitializeMatrices(char *cellname)
       Leaves++;
       if (Leaves > MAX_LEAVES) continue; /* keep going within the for loop */
 
-      tp = LookupCell(ob->model);
+      tp = LookupCell(ob->model.class);
       if (tp == NULL || (tp->class != CLASS_SUBCKT) || tp->embedding == NULL)
 	LEVEL(Leaves) = 0;
       else LEVEL(Leaves) = ((struct embed *)(tp->embedding))->level;
@@ -315,7 +315,6 @@ void PrintE(FILE *outfile, int E)
 
 
 #if 0
-INLINE
 int UsedLeaves(int E1, int E2)
 /* returns the number of leaves in E1 + E2, which are assumed independent */
 {
@@ -327,7 +326,6 @@ int UsedLeaves(int E1, int E2)
 #endif
 
 
-INLINE
 int CommonNodes(int E1, int E2, int IncludeGlobals)
 /* returns the number of nodes that E1 and E2 share */
 /* if IncludeGlobals == 0, do not count large connectivity nodes */
@@ -350,7 +348,6 @@ int CommonNodes(int E1, int E2, int IncludeGlobals)
   return(result);
 }
 
-INLINE
 int GlobalNodes(int E)
 /* return the number of global nodes that E contacts */
 /* for now, global nodes are just cell ports */
@@ -514,8 +511,8 @@ int OpenEmbeddingFile(char *cellname, char *filename)
 /* returns 1 if OK */
 {
   struct nlist *tp;
-  char outfilename[200];
-  char logfilename[200];
+  char outfilename[MAX_STR_LEN];
+  char logfilename[MAX_STR_LEN];
 
   tp = LookupCell(cellname);
   if (tp == NULL) {
@@ -588,9 +585,9 @@ void EmbedCells(char *cellname, enum EmbeddingStrategy strategy)
   for (ob = tp->cell; ob != NULL; ob = ob->next)
     if (ob->type == FIRSTPIN) {
       struct nlist *tp2;
-      tp2 = LookupCell(ob->model);
+      tp2 = LookupCell(ob->model.class);
       if (!(tp2->dumped) && (tp2->class == CLASS_SUBCKT))
-	EmbedCells(ob->model,strategy);
+	EmbedCells(ob->model.class,strategy);
     }
   switch (strategy) {
   case bottomup: EmbedCell(cellname, NULL);
@@ -786,7 +783,7 @@ void SetupArray(char *prompt1, char *prompt2, char *prompt3, int *data,
                 void (*proc)(void))
 {
   int i, oldfanout;
-  char name[100];
+  char name[MAX_STR_LEN];
 
   Printf(prompt1);
   for (i = 1; i <= MAX_TREE_DEPTH; i++) 
@@ -795,7 +792,7 @@ void SetupArray(char *prompt1, char *prompt2, char *prompt3, int *data,
 
   oldfanout = 1;
   for (i = 1; i <= MAX_TREE_DEPTH; i++) {
-    char prompt[100];
+    char prompt[MAX_STR_LEN];
     int newfanout;
     sprintf(prompt, prompt2, i);
     promptstring(prompt, name);
@@ -825,7 +822,7 @@ void SetupArrayFromString(char *prompt1, char *prompt3, int *data,
                 void (*proc)(void), char *text)
 {
   int i, oldfanout, newfanout;
-  char string[100];
+  char string[MAX_STR_LEN];
   char *ch;
   char *endch;
 
@@ -932,7 +929,7 @@ void ToggleDebug(void)
 void DescribeCell(char *name, int detail)
 {
   Printf("Cell: %s contains %d instances, %d nodes and %d ports\n", name, 
-	 NumberOfInstances(name),  RenumberNodes(name), NumberOfPorts(name));
+	 NumberOfInstances(name),  RenumberNodes(name), NumberOfPorts(name, -1));
   PrintEmbeddingTree(stdout,name,detail);
 }
 
@@ -965,18 +962,14 @@ void ProtoPrintParameters(void)
 void PROTOCHIP(void)
 /* a simple command interpreter to manage embedding/routing */
 {
-  char name[100];
+  char name[MAX_STR_LEN];
   char ch;
   
   InitializeFanout();
   InitializeMinCommonNodes();
   InitializeMinUsedLeaves();
   setjmp(jmpenv);
-#if defined(CPLUSPLUS) && defined(SIG_PF)
-  signal(SIGINT,(SIG_PF)handler);
-#else
   signal(SIGINT,handler);
-#endif
   do {
     promptstring("PROTOCHIP command: ", name);
     ch = name[0];
@@ -1089,8 +1082,8 @@ void PROTOCHIP(void)
       promptstring("Cell to count sub-graphs: ",name);
       CountSubGraphs(name);
       break;
-    case 'h': PrintCellHashTable(0, NULL); break;
-    case 'H': PrintCellHashTable(1, NULL); break;
+    case 'h': PrintCellHashTable(0, -1); break;
+    case 'H': PrintCellHashTable(1, -1); break;
     case 'F':
       promptstring("Enter leaf pinout: ",name);
       LeafPins = atoi(name);
@@ -1143,7 +1136,7 @@ void PROTOCHIP(void)
 
       oldfanout = 1;
       for (i = 1; i <= MAX_TREE_DEPTH; i++) {
-	char prompt[100];
+	char prompt[MAX_STR_LEN];
 	int newfanout;
 	sprintf(prompt,"Fanout for level %d (0 to quit): ",i);
 	promptstring(prompt, name);
@@ -1175,7 +1168,7 @@ void PROTOCHIP(void)
 
       oldfanout = 1;
       for (i = 1; i <= MAX_TREE_DEPTH; i++) {
-	char prompt[100];
+	char prompt[MAX_STR_LEN];
 	int newfanout;
 	sprintf(prompt,"Common nodes for level %d (0 to quit): ",i);
 	promptstring(prompt, name);
@@ -1207,7 +1200,7 @@ void PROTOCHIP(void)
 
       oldfanout = 1;
       for (i = 1; i <= MAX_TREE_DEPTH; i++) {
-	char prompt[100];
+	char prompt[MAX_STR_LEN];
 	int newfanout;
 	sprintf(prompt,"Used leaves for level %d (0 to quit): ",i);
 	promptstring(prompt, name);
@@ -1254,9 +1247,5 @@ void PROTOCHIP(void)
       break;
     }
   } while (ch != 'q');
-#if defined(CPLUSPLUS) && defined(SIG_PF)
-  signal(SIGINT,(SIG_PF)SIG_DFL);
-#else
   signal(SIGINT,SIG_DFL);
-#endif
 }
